stream property
The stream of timed states to observe.
Each event in the stream should be a TimedValue containing the state and its timestamp.
Implementation
final Stream<TimedValue<S>> stream;
The stream of timed states to observe.
Each event in the stream should be a TimedValue containing the state and its timestamp.
final Stream<TimedValue<S>> stream;