Next<T> class
final
Represents the temporal operator NEXT (X or ○).
Formula: X operand
Evaluates to true at time t if the operand formula holds at the
next time point t+1. Requires the trace to have a state at t+1.
If time t is the last point in the trace, X operand is false.
Evaluation Details:
- If
i+1is beyond the end of the trace,Nextevaluates tofalse.
Properties
Methods
-
always(
) → Always< T> -
Creates an ALWAYS (Globally) operator for this formula.
G(this)inherited -
and(
Formula< T> formula) → And<T> -
Creates a logical conjunction (AND) with another
formula.this && formulainherited -
eventually(
) → Eventually< T> -
Creates an EVENTUALLY (Finally) operator for this formula.
F(this)inherited -
implies(
Formula< T> formula) → Implies<T> -
Creates a logical implication (IMPLIES) with another
formula.this -> formulainherited -
next(
) → Next< T> -
Creates a NEXT operator for this formula.
X(this)inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Not< T> -
Creates a logical negation (NOT) of this formula.
!thisinherited -
or(
Formula< T> formula) → Or<T> -
Creates a logical disjunction (OR) with another
formula.this || formulainherited -
release(
Formula< T> formula) → Release<T> -
Creates a RELEASE operator with another
formula.this R formulainherited -
toString(
) → String -
Returns a string representation of the formula, useful for debugging.
override
-
until(
Formula< T> formula) → Until<T> -
Creates an UNTIL operator with another
formula.this U formulainherited -
weakUntil(
Formula< T> formula) → WeakUntil<T> -
Creates a WEAK UNTIL operator with another
formula.this W formulainherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited