StreamMtlChecker<S> class

Provides periodic evaluation of a temporal logic Formula (LTL/MTL) against a stream of time-stamped values. Incoming events are accumulated into an internal trace and evaluated on every new event.

Type parameter S defines the type of the state values in the trace.

Constructors

StreamMtlChecker(Stream<TimedValue<S>> stream, {required Formula<S> formula, TimedValue<S>? initialValue, StreamEvaluationStart evaluationStart = StreamEvaluationStart.beginning})
Creates a StreamMtlChecker that listens to the specified stream of timed states and evaluates the given formula. If initialValue is provided, it is used as the first trace event before any stream emissions. Evaluation occurs on each new event and immediately for the initial value.

Properties

buildTraceSnapshot → TraceSnapshotBuilder<TraceEvent<S>, Trace<S>>
finalinherited
evaluationStart StreamEvaluationStart
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isTraceEmpty bool
no setterinherited
resultStream Stream<EvaluationResult>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendTraceEntry(TraceEvent<S> entry) → void
inherited
buildCurrentTrace() Trace<S>
inherited
clearTrace() → void
inherited
closeResultStream() → void
inherited
dispose() → void
inherited
emitResult(EvaluationResult result) → void
inherited
evaluateCurrent() EvaluationResult
initializeWithInitialEvaluation(EvaluationResult evaluateInitial()) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInput(TimedValue<S> input) → void
onSourceDone() → void
inherited
publishErrorAndClose(Object error, [StackTrace? stackTrace]) → void
inherited
resolveStartIndex() int
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited