formula property
The LTL formula to check against the trace derived from the stream.
This formula defines the temporal property to be monitored.
Implementation
final Formula<S> formula;
The LTL formula to check against the trace derived from the stream.
This formula defines the temporal property to be monitored.
final Formula<S> formula;